:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

Grappelli 2.11.x Release Notes
=============================

**Grappelli 2.11.x is compatible with Django 2.0**.

Update from Grappelli 2.10.x
----------------------------

* Update Django to 2.0 and check https://docs.djangoproject.com/en/dev/releases/2.0/
* Update Grappelli to 2.11.x
